use utf8;

package SemanticWeb::Schema::MedicalSpecialty;

# ABSTRACT: Any specific branch of medical science or practice

use Moo;

extends qw/ SemanticWeb::Schema::MedicalEnumeration SemanticWeb::Schema::Specialty /;


use MooX::JSON_LD 'MedicalSpecialty';
use Ref::Util qw/ is_plain_hashref /;
# RECOMMEND PREREQ: Ref::Util::XS

use namespace::autoclean;

our $VERSION = 'v8.0.0';




1;

__END__

=pod

=encoding UTF-8

=head1 NAME

SemanticWeb::Schema::MedicalSpecialty - Any specific branch of medical science or practice

=head1 VERSION

version v8.0.0

=head1 DESCRIPTION

Any specific branch of medical science or practice. Medical specialities
include clinical specialties that pertain to particular organ systems and
their respective disease states, as well as allied health specialties.
Enumerated type.

=head1 SEE ALSO

L<SemanticWeb::Schema::Specialty>

=head1 SOURCE

The development version is on github at L<https://github.com/robrwo/SemanticWeb-Schema>
and may be cloned from L<git://github.com/robrwo/SemanticWeb-Schema.git>

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website
L<https://github.com/robrwo/SemanticWeb-Schema/issues>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

Robert Rothenberg <rrwo@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018-2020 by Robert Rothenberg.

This is free software, licensed under:

  The Artistic License 2.0 (GPL Compatible)

=cut
