use utf8;

package SemanticWeb::Schema::CivicStructure;

# ABSTRACT: A public structure

use Moo;

extends qw/ SemanticWeb::Schema::Place /;


use MooX::JSON_LD 'CivicStructure';
use Ref::Util qw/ is_plain_hashref /;
# RECOMMEND PREREQ: Ref::Util::XS

use namespace::autoclean;

our $VERSION = 'v8.0.0';


has opening_hours => (
    is        => 'rw',
    predicate => '_has_opening_hours',
    json_ld   => 'openingHours',
);





1;

__END__

=pod

=encoding UTF-8

=head1 NAME

SemanticWeb::Schema::CivicStructure - A public structure

=head1 VERSION

version v8.0.0

=head1 DESCRIPTION

A public structure, such as a town hall or concert hall.

=head1 ATTRIBUTES

=head2 C<opening_hours>

C<openingHours>

=for html <p>The general opening hours for a business. Opening hours can be specified
as a weekly time range, starting with days, then times per day. Multiple
days can be listed with commas ',' separating each day. Day or time ranges
are specified using a hyphen '-'.<br/><br/> <ul> <li>Days are specified
using the following two-letter combinations: <code>Mo</code>,
<code>Tu</code>, <code>We</code>, <code>Th</code>, <code>Fr</code>,
<code>Sa</code>, <code>Su</code>.</li> <li>Times are specified using 24:00
time. For example, 3pm is specified as <code>15:00</code>. </li> <li>Here
is an example: <code>&lt;time itemprop="openingHours" datetime=&quot;Tu,Th
16:00-20:00&quot;&gt;Tuesdays and Thursdays 4-8pm&lt;/time&gt;</code>.</li>
<li>If a business is open 7 days a week, then it can be specified as
<code>&lt;time itemprop=&quot;openingHours&quot;
datetime=&quot;Mo-Su&quot;&gt;Monday through Sunday, all
day&lt;/time&gt;</code>.</li> </ul> <p>

A opening_hours should be one of the following types:

=over

=item C<Str>

=back

=head2 C<_has_opening_hours>

A predicate for the L</opening_hours> attribute.

=head1 SEE ALSO

L<SemanticWeb::Schema::Place>

=head1 SOURCE

The development version is on github at L<https://github.com/robrwo/SemanticWeb-Schema>
and may be cloned from L<git://github.com/robrwo/SemanticWeb-Schema.git>

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website
L<https://github.com/robrwo/SemanticWeb-Schema/issues>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

Robert Rothenberg <rrwo@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018-2020 by Robert Rothenberg.

This is free software, licensed under:

  The Artistic License 2.0 (GPL Compatible)

=cut
